@@ -11,14 +11,14 @@ from packaging.version import Version
 
 from .aggregations import Aggregation, Dim, _atleast_1d, quantile_new_dims_func
 from .core import (
-    ReindexStrategy,
     _convert_expected_groups_to_index,
     _get_expected_groups,
     _validate_expected_groups,
     groupby_reduce,
 )
-from .core import rechunk_for_blockwise as rechunk_array_for_blockwise
-from .core import rechunk_for_cohorts as rechunk_array_for_cohorts
+from .rechunk import rechunk_for_blockwise as rechunk_array_for_blockwise
+from .rechunk import rechunk_for_cohorts as rechunk_array_for_cohorts
+from .reindex import ReindexStrategy
 
 if TYPE_CHECKING:
     from xarray.core.types import T_DataArray, T_Dataset
@@ -257,7 +257,7 @@ def xarray_reduce(
     try:
         from xarray.indexes import PandasMultiIndex
     except ImportError:
-        PandasMultiIndex = tuple()  # type: ignore[assignment, misc]
+        PandasMultiIndex = tuple()  # type: ignore[misc,assignment,unused-ignore]
 
     more_drop = set()
     for var in maybe_drop:
